@@ -1,13 +1,13 @@
-# -*- coding: utf-8 -*-
 """
     sphinxcontrib.mat_types
     ~~~~~~~~~~~~~~~~~~~~~~~
 
     Types for MATLAB.
 
-    :copyright: Copyright 2014 Mark Mikofski
+    :copyright: Copyright 2014-2024 by the sphinxcontrib-matlabdomain team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
+
 from io import open  # for opening files with encoding in Python 2
 import os
 from copy import copy
@@ -54,6 +54,8 @@ MATLAB_CLASS_ATTRIBUTE_TYPES = {
     "Hidden": bool,
     "InferiorClasses": list,
     "Sealed": bool,
+    "SharedTestFixtures": list,
+    "TestTags": list,
 }
 
 # From:
@@ -96,9 +98,15 @@ MATLAB_METHOD_ATTRIBUTE_TYPES = {
     "TestClassTeardown": bool,
     "TestMethodSetup": bool,
     "TestMethodTeardown": bool,
+    "TestTags": list,
 }
 
 
+MATLAB_FUNC_BRACES_BEGIN = tuple(zip((Token.Punctuation,) * 2, ("(", "{")))
+MATLAB_FUNC_BRACES_END = tuple(zip((Token.Punctuation,) * 2, (")", "}")))
+MATLAB_PROP_BRACES_BEGIN = tuple(zip((Token.Punctuation,) * 3, ("(", "{", "[")))
+MATLAB_PROP_BRACES_END = tuple(zip((Token.Punctuation,) * 3, (")", "}", "]")))
+
 # Dictionary containing all MATLAB entities that are found in `matlab_src_dir`.
 # The dictionary keys are both the full dotted path, relative to the root.
 # Further, "short names" are added. Example:
@@ -196,25 +204,39 @@ def populate_entities_table(obj, path=""):
                 populate_entities_table(o, fullpath)
 
 
+def try_get_module_entity_or_default(entity_name):
+    maybe_mod = entities_table.get(entity_name)
+    if isinstance(maybe_mod, dict):
+        return maybe_mod["mod"]
+    return maybe_mod
+
+
 def analyze(app):
     # Using the "MatObject.matlabify" and "MatModule.safe_getmembers" the
     # `matlab_src_dir` is recursively scanned for MATLAB objects only once.
     # All entities found are stored in globally available `entities_table`
 
-    basedir = app.env.config.matlab_src_dir
-    MatObject.basedir = basedir  # set MatObject base directory
-    MatObject.sphinx_env = app.env  # pass env to MatObject cls
-    MatObject.sphinx_app = app  # pass app to MatObject cls
-    entities_table.clear()
-
-    if basedir is None:
+    if app.env.config.matlab_src_dir is None:
         logger.debug(
             "[sphinxcontrib-matlabdomain] matlab_src_dir is None, skipping parsing."
         )
         return
 
+    # Interpret `matlab_src_dir` relative to the sphinx source directory.
+    basedir = os.path.normpath(
+        os.path.join(app.env.srcdir, app.env.config.matlab_src_dir)
+    )
+    MatObject.basedir = basedir  # set MatObject base directory
+    MatObject.sphinx_env = app.env  # pass env to MatObject cls
+    MatObject.sphinx_app = app  # pass app to MatObject cls
+
+    entities_table.clear()
+    entities_name_map.clear()
+
     # Set the root object and get root members.
     root = MatObject.matlabify("")
+    if not root:
+        return
     root.safe_getmembers()
     recursive_find_all(root)
 
@@ -241,9 +263,7 @@ def analyze(app):
             return False
 
         parts = name.split(".")
-        if "@" in name and parts[-1] != "private":
-            return True
-        return False
+        return parts[-1].startswith("@")
 
     class_folder_modules = {
         k: v for k, v in entities_table.items() if isClassFolderModule(k, v)
@@ -253,6 +273,9 @@ def analyze(app):
         # Find the class entity class.
         class_entities = [e for e in cf_entity.entities if isinstance(e[1], MatClass)]
         func_entities = [e for e in cf_entity.entities if isinstance(e[1], MatFunction)]
+
+        if not class_entities:
+            continue
         assert len(class_entities) == 1
         cls = class_entities[0][1]
 
@@ -278,10 +301,27 @@ def analyze(app):
     #
     # NOTE: Does not yet work with class folders
     short_names = {}
+    long_names = entities_table.keys()
     for name, entity in entities_table.items():
         short_name = shortest_name(name)
-        if short_name != name:
-            short_names[short_name] = entity
+        if (
+            short_name != name
+            and not (short_name in long_names and name in long_names)
+            or short_name in long_names
+            and (entity.ref_role() == "func" or entity.ref_role() == "class")
+            and entities_table[short_name].ref_role() == "mod"
+        ):
+            # Only handle the below special case when overwriting entries in entities_table will not
+            # introduce conflicts
+            if short_name in entities_table:
+                # Special Case - ClassName/ClassName.m
+                existing_entity = entities_table[short_name]
+                short_names[short_name] = {
+                    entity.ref_role(): entity,
+                    existing_entity.ref_role(): existing_entity,
+                }
+            else:
+                short_names[short_name] = entity
             entities_name_map[short_name] = short_name
 
     entities_table.update(short_names)
@@ -397,7 +437,7 @@ class MatObject(object):
         if os.path.isdir(fullpath):
             if package.startswith("_") or package.startswith("."):
                 return None
-            mod = entities_table.get(package)
+            mod = try_get_module_entity_or_default(package)
             if mod:
                 logger.debug(
                     "[sphinxcontrib-matlabdomain] Module %s already loaded.", package
@@ -767,7 +807,11 @@ class MatMixin(object):
             or (self.tokens[idx][0] == Token.Text and self.tokens[idx][1] != "\n")
         ):
             idx += 1
-        return idx - idx0  # property spec count.
+
+        count = idx - idx0  # property spec count.
+        propspec = "".join([content for _, content in self.tokens[idx0 : idx0 + count]])
+        propspec = propspec.strip()
+        return count, propspec
 
     def _is_newline(self, idx):
         """Returns true if the token at index is a newline"""
@@ -954,9 +998,9 @@ class MatFunction(MatObject):
                 elif kw == (Token.Keyword, "end") and not lastkw:
                     kw_end -= 1
                 # save last punctuation
-                elif kw in list(zip((Token.Punctuation,) * 2, ("(", "{"))):
+                elif kw in MATLAB_FUNC_BRACES_BEGIN:
                     lastkw += 1
-                elif kw in list(zip((Token.Punctuation,) * 2, (")", "}"))):
+                elif kw in MATLAB_FUNC_BRACES_END:
                     lastkw -= 1
                 try:
                     kw = tks.pop()
@@ -1035,10 +1079,10 @@ class MatClass(MatMixin, MatObject):
 
             # class "attributes"
             self.attrs, idx = self.attributes(idx, MATLAB_CLASS_ATTRIBUTE_TYPES)
-            # =====================================================================
-            # classname
-            idx += self._blanks(idx)  # skip blanks
-            if self._tk_ne(idx, (Token.Name, self.name)):
+
+            # Check if self.name matches the name in the file.
+            idx += self._blanks(idx)
+            if not self.tokens[idx][1] == self.name:
                 logger.warning(
                     "[sphinxcontrib-matlabdomain] Unexpected class name: '%s'."
                     " Expected '%s' in '%s'.",
@@ -1164,36 +1208,29 @@ class MatClass(MatMixin, MatObject):
                                     break
 
                         # with "%:" directive trumps docstring after property
-                        if self.tokens[idx][0] is Token.Name:
+                        isTokenName = self.tokens[idx][0] is Token.Name
+                        isTokenNameSubtype = self.tokens[idx][0] in Token.Name.subtypes
+                        if isTokenName or isTokenNameSubtype:
                             prop_name = self.tokens[idx][1]
                             idx += 1
+                            if isTokenNameSubtype:
+                                logger.debug(
+                                    "[sphinxcontrib-matlabdomain] WARNING %s.%s.%s is a builtin name.",
+                                    self.module,
+                                    self.name,
+                                    prop_name,
+                                )
+
                             # Initialize property if it was not already done
                             if prop_name not in self.properties.keys():
                                 self.properties[prop_name] = {"attrs": attr_dict}
 
-                            # skip size, class and functions specifiers
-                            # TODO: Parse old and new style property extras
-                            idx += self._propspec(idx)
-
-                            if self._tk_eq(idx, (Token.Punctuation, ";")):
-                                continue
-
-                        # subtype of Name EG Name.Builtin used as Name
-                        elif self.tokens[idx][0] in Token.Name.subtypes:
-                            prop_name = self.tokens[idx][1]
-                            logger.debug(
-                                "[sphinxcontrib-matlabdomain] WARNING %s.%s.%s is a builtin name.",
-                                self.module,
-                                self.name,
-                                prop_name,
-                            )
-                            self.properties[prop_name] = {"attrs": attr_dict}
-                            idx += 1
-
-                            # skip size, class and functions specifiers
-                            # TODO: Parse old and new style property extras
-                            idx += self._propspec(idx)
+                            # Capture (dimensions) class {validators} as "specs"
+                            # https://mathworks.com/help/matlab/matlab_oop/defining-properties.html
+                            count, propspec = self._propspec(idx)
+                            self.properties[prop_name]["specs"] = propspec
 
+                            idx = idx + count
                             if self._tk_eq(idx, (Token.Punctuation, ";")):
                                 continue
 
@@ -1219,6 +1256,10 @@ class MatClass(MatMixin, MatObject):
                                 docstring += "\n"
                                 self.properties[prop_name]["docstring"] = docstring
                                 idx += 1
+                        elif self.tokens[idx][0] is Token.Comment:
+                            # Comments seperated with blank lines.
+                            idx = idx - 1
+                            continue
                         else:
                             logger.warning(
                                 "sphinxcontrib-matlabdomain] Expected property in %s.%s - got %s",
@@ -1236,7 +1277,7 @@ class MatClass(MatMixin, MatObject):
                             idx += self._blanks(idx)  # skip blanks
                             # concatenate default value until newline or comment
                             default = ""
-                            punc_ctr = 0  # punctuation placeholder
+                            brace_count = 0
                             # keep reading until newline or comment
                             # only if all punctuation pairs are closed
                             # and comment is **not** continuation ellipsis
@@ -1245,7 +1286,7 @@ class MatClass(MatMixin, MatObject):
                                     not self._is_newline(idx)
                                     and self.tokens[idx][0] is not Token.Comment
                                 )
-                                or punc_ctr > 0
+                                or brace_count > 0
                                 or (
                                     self.tokens[idx][0] is Token.Comment
                                     and self.tokens[idx][1].startswith("...")
@@ -1253,15 +1294,12 @@ class MatClass(MatMixin, MatObject):
                             ):
                                 token = self.tokens[idx]
                                 # default has an array spanning multiple lines
-                                if token in list(
-                                    zip((Token.Punctuation,) * 3, ("(", "{", "["))
-                                ):
-                                    punc_ctr += 1  # increment punctuation counter
+                                # keep track of braces
+                                if token in MATLAB_PROP_BRACES_BEGIN:
+                                    brace_count += 1
                                 # look for end of array
-                                elif token in list(
-                                    zip((Token.Punctuation,) * 3, (")", "}", "]"))
-                                ):
-                                    punc_ctr -= 1  # decrement punctuation counter
+                                elif token in MATLAB_PROP_BRACES_END:
+                                    brace_count -= 1
                                 # Pygments treats continuation ellipsis as comments
                                 # text from ellipsis until newline is in token
                                 elif token[0] is Token.Comment and token[1].startswith(
@@ -1273,7 +1311,9 @@ class MatClass(MatMixin, MatObject):
                                         default += "\n"
                                         idx += 1
                                     continue
-                                elif self._is_newline(idx - 1):
+                                elif self._is_newline(idx - 1) and not self._is_newline(
+                                    idx
+                                ):
                                     idx += self._blanks(idx)
                                     continue
                                 elif token[0] is Token.Text and token[1] == " ":
@@ -1324,6 +1364,7 @@ class MatClass(MatMixin, MatObject):
                         meth_tk = self.tokens[idx]
                         if (
                             meth_tk[0] is Token.Name
+                            or meth_tk[0] is Token.Name.Builtin
                             or meth_tk[0] is Token.Name.Function
                             or (
                                 meth_tk[0] is Token.Keyword
@@ -1579,7 +1620,7 @@ class MatProperty(MatObject):
         self.attrs = attrs["attrs"]
         self.default = attrs["default"]
         self.docstring = attrs["docstring"]
-        # self.class = attrs['class']
+        self.specs = attrs["specs"]
 
     def ref_role(self):
         """Returns role to use for references to this object (e.g. when generating auto-links)"""
@@ -1743,9 +1784,11 @@ class MatModuleAnalyzer(object):
             if isinstance(entry, MatcodeError):
                 raise entry
             return entry
-        mod = entities_table[modname]
-        if mod:
+        mod = try_get_module_entity_or_default(modname)
+        if isinstance(mod, MatModule):
             obj = cls.for_folder(mod.path, modname)
+        elif isinstance(mod, MatClass):
+            obj = cls.for_folder(mod.module, modname)
         else:
             err = MatcodeError("error importing %r" % modname)
             cls.cache["module", modname] = err
@@ -1780,7 +1823,7 @@ class MatModuleAnalyzer(object):
         attr_visitor_collected = {}
         attr_visitor_tagorder = {}
         tagnumber = 0
-        mod = entities_table[self.modname]
+        mod = try_get_module_entity_or_default(self.modname)
 
         # walk package tree
         for k, v in mod.safe_getmembers():
