@@ -1,13 +1,13 @@
-# -*- coding: utf-8 -*-
 """
     sphinxcontrib.matlab
     ~~~~~~~~~~~~~~~~~~~~
 
     The MATLAB domain.
 
-    :copyright: Copyright 2007-2011 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2014-2024 by the sphinxcontrib-matlabdomain team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
+
 from . import mat_documenters as doc
 from . import mat_directives
 from . import mat_types
@@ -257,7 +257,7 @@ class MatObject(ObjectDescription):
     def add_target_and_index(self, name_cls, sig, signode):
         modname = self.options.get("module", self.env.temp_data.get("mat:module"))
 
-        if self.env.config.matlab_short_links:
+        if self.env.config.matlab_short_links and not name_cls[0] == modname:
             # modname is only used for package names
             # - "target.+package" => "package"
             # - "target" => ""
@@ -862,6 +862,7 @@ def setup(app):
     app.add_config_value("matlab_src_encoding", None, "env")
     app.add_config_value("matlab_keep_package_prefix", False, "env")
     app.add_config_value("matlab_show_property_default_value", False, "env")
+    app.add_config_value("matlab_show_property_specs", False, "env")
     app.add_config_value("matlab_short_links", False, "env")
     app.add_config_value("matlab_auto_link", None, "env")
     app.add_config_value("matlab_class_signature", False, "env")
@@ -906,13 +907,6 @@ def setup(app):
         "mat", "autodata", mat_directives.MatlabAutodocDirective
     )
 
-    app.registry.add_documenter(
-        "mat:instanceattribute", doc.MatInstanceAttributeDocumenter
-    )
-    app.add_directive_to_domain(
-        "mat", "autoinstanceattribute", mat_directives.MatlabAutodocDirective
-    )
-
     app.registry.add_documenter("mat:application", doc.MatApplicationDocumenter)
     app.add_directive_to_domain(
         "mat", "autoapplication", mat_directives.MatlabAutodocDirective
