@@ -13,11 +13,11 @@ classdef ClassExample < handle
     % package.ClassBar.bars, package.ClassBar.doFoo.
 
     properties
-        a % a property
+        a (1,:) {mustBeScalarOrEmpty}  = 42 % a property
         b = 10 % a property with default value
         c = [10;
-             20;
-             30]; % a property with multiline default value
+            20;
+            30]; % a property with multiline default value
     end
     methods
         function mc = ClassExample(a)
@@ -27,9 +27,9 @@ classdef ClassExample < handle
         end
 
         function c = mymethod(obj, b)
-        % A method in :class:`ClassExample`
-        %
-        % :param b: an input to :meth:`mymethod`
+            % A method in :class:`ClassExample`
+            %
+            % :param b: an input to :meth:`mymethod`
             for n = 1:10
                 if n > 5
                     c = obj.a + b;
