@@ -52,6 +52,10 @@ def test_module(mod):
     expected_items = {
         "+package",
         "@ClassFolder",
+        "@ClassFolderWithoutClassDefinition",
+        "@ClassFolderUsingBuiltins",
+        "@EmptyClassFolder",
+        "@NestedClassFolder",
         "Application",
         "ClassAbstract",
         "ClassExample",
@@ -111,6 +115,11 @@ def test_module(mod):
         "ClassWithPropertyValidators",
         "ClassWithTrailingCommentAfterBases",
         "ClassWithTrailingSemicolons",
+        "ClassWithSeperatedComments",
+        "ClassWithKeywordsAsFieldnames",
+        "ClassWithPropertyCellValues",
+        "ClassWithTests",
+        "arguments",
     }
     assert all_items == expected_items
     assert mod.getter("__name__") in entities_table
@@ -132,7 +141,7 @@ def test_classes(mod):
     assert cls.bases == ["handle", "my.super.Class"]
     assert cls.attrs == {}
     assert cls.properties == {
-        "x": {"attrs": {}, "default": None, "docstring": " a property"}
+        "x": {"attrs": {}, "default": None, "docstring": " a property", "specs": ""}
     }
     assert cls.getter("__doc__") == " a handle class\n\n :param x: a variable\n"
 
@@ -152,11 +161,13 @@ def test_abstract_class(mod):
             "default": None,
             "docstring": " y variable",
             "attrs": {"GetAccess": "private", "SetAccess": "private"},
+            "specs": "",
         },
         "version": {
             "default": "'0.1.1-beta'",
             "docstring": " version",
             "attrs": {"Constant": True},
+            "specs": "",
         },
     }
     assert (
@@ -234,6 +245,7 @@ def test_folder_class(mod):
             "attrs": {},
             "default": None,
             "docstring": " a property of a class folder",
+            "specs": "",
         }
     }
 
