@@ -320,22 +320,26 @@ def test_PropTypeOld():
             "docstring": None,
             "attrs": {},
             "default": "'none'",
-        },  # 'type': ['char']
+            "specs": "@char",
+        },
         "pos": {
             "docstring": None,
             "attrs": {},
             "default": "zeros(3,1)",
-        },  # 'type': ['double', 'vector'],
+            "specs": "@double vector",
+        },
         "rotm": {
             "docstring": None,
             "attrs": {},
             "default": "zeros(3,3)",
-        },  # 'type': ['double', 'matrix'],
+            "specs": "@double matrix",
+        },
         "idx": {
             "docstring": None,
             "attrs": {},
             "default": "0",
-        },  # 'type': ['uint8', 'scalar'],
+            "specs": "@uint8 scalar",
+        },
     }
 
 
@@ -616,7 +620,12 @@ def test_ClassWithGetterSetter():
     assert obj.name == "ClassWithGetterSetter"
     assert list(obj.methods.keys()) == ["ClassWithGetterSetter"]
     assert obj.properties == {
-        "a": {"docstring": " A nice property", "attrs": {}, "default": None}
+        "a": {
+            "docstring": " A nice property",
+            "attrs": {},
+            "default": None,
+            "specs": "",
+        }
     }
 
 
@@ -629,7 +638,7 @@ def test_ClassWithDoubleQuotedString():
     assert obj.name == "ClassWithDoubleQuotedString"
     assert set(obj.methods.keys()) == set(["ClassWithDoubleQuotedString", "method1"])
     assert obj.properties == {
-        "Property1": {"docstring": None, "attrs": {}, "default": None}
+        "Property1": {"docstring": None, "attrs": {}, "default": None, "specs": ""}
     }
 
 
@@ -845,5 +854,65 @@ def test_ClassWithTrailingSemicolons():
     ]
 
 
+def test_ClassWithSeperatedComments():
+    mfile = os.path.join(TESTDATA_ROOT, "ClassWithSeperatedComments.m")
+    obj = mat_types.MatObject.parse_mfile(
+        mfile, "ClassWithSeperatedComments", "test_data"
+    )
+    assert obj.name == "ClassWithSeperatedComments"
+    assert obj.bases == []
+    assert "prop" in obj.properties
+    prop = obj.properties["prop"]
+    assert prop["docstring"] == " Another comment\n"
+
+
+def test_ClassWithKeywordsAsFieldnames():
+    mfile = os.path.join(TESTDATA_ROOT, "ClassWithKeywordsAsFieldnames.m")
+    obj = mat_types.MatObject.parse_mfile(
+        mfile, "ClassWithKeywordsAsFieldnames", "test_data"
+    )
+    assert obj.name == "ClassWithKeywordsAsFieldnames"
+    assert obj.bases == []
+    assert "a" in obj.properties
+    assert "b" in obj.properties
+    assert "c" in obj.properties
+    assert "calculate" in obj.methods
+    meth = obj.methods["calculate"]
+    assert meth.docstring == " Returns the value of `d`\n"
+
+
+def test_ClassWithNamedAsArguments():
+    mfile = os.path.join(TESTDATA_ROOT, "arguments.m")
+    obj = mat_types.MatObject.parse_mfile(mfile, "arguments", "test_data")
+    assert obj.name == "arguments"
+    assert obj.bases == ["handle", "matlab.mixin.Copyable"]
+    assert "value" in obj.properties
+    meth = obj.methods["arguments"]
+    assert meth.docstring == " Constructor for arguments\n"
+    meth = obj.methods["add"]
+    assert meth.docstring == " Add new argument\n"
+
+
+def test_ClassWithPropertyCellValues():
+    mfile = os.path.join(TESTDATA_ROOT, "ClassWithPropertyCellValues.m")
+    obj = mat_types.MatObject.parse_mfile(
+        mfile, "ClassWithPropertyCellValues", "test_data"
+    )
+    assert obj.name == "ClassWithPropertyCellValues"
+    assert obj.bases == []
+    assert "fields" in obj.properties
+    assert "getLevel" in obj.methods
+
+
+def test_ClassWithTests():
+    mfile = os.path.join(TESTDATA_ROOT, "ClassWithTests.m")
+    obj = mat_types.MatObject.parse_mfile(mfile, "ClassWithTests", "test_data")
+    assert obj.name == "ClassWithTests"
+    assert obj.bases == ["matlab.unittest.TestCase"]
+    assert "testRunning" in obj.methods
+    testRunning = obj.methods["testRunning"]
+    assert testRunning.attrs["TestTags"] == ["'Unit'"]
+
+
 if __name__ == "__main__":
     pytest.main([os.path.abspath(__file__)])
